---
title: Use CSS to solve common problems
slug: Learn/CSS/Howto
tags:
  - Beginner
  - CSS
  - Learn
---
{{LearnSidebar}}

This page rounds up questions and answers, and other material on the MDN site that can help you to solve common CSS problems.

## Styling boxes

- [How do I add a drop-shadow to an element?](/en-US/docs/Learn/CSS/Howto/Add_a_shadow)
  - : Shadows can be added to boxes with the {{cssxref("box-shadow")}} property. This tutorial explains how it works and shows an example.
- [How do I fill a box with an image without distorting the image?](/en-US/docs/Learn/CSS/Howto/Fill_a_box_with_an_image)
  - : The {{cssxref("object-fit")}} property provides different ways to fit an image into a box which has a different aspect ratio, and you can find out how to use them in this tutorial.
- [Which methods can be used to style boxes?](/en-US/docs/Learn/CSS/Howto/create_fancy_boxes)
  - : A rundown of the different properties that might be useful when styling boxes using CSS.
- [How can I make elements semi-transparent?](/en-US/docs/Learn/CSS/Howto/Make_box_transparent)
  - : The {{cssxref("opacity")}} property and color values with an alpha channel can be used for this; find out which one to use when.

### Box styling lessons and guides

- [The Box Model](/en-US/docs/Learn/CSS/Building_blocks/The_box_model)
- [Styling backgrounds and borders](/en-US/docs/Learn/CSS/Building_blocks/Backgrounds_and_borders)

## CSS and text

- [How do I add a drop-shadow to text?](/en-US/docs/Learn/CSS/Howto/Add_a_text_shadow)
  - : Shadows can be added to text with the {{cssxref("text-shadow")}} property. This tutorial explains how it works and shows an example.
- [How do I highlight the first line of a paragraph?](/en-US/docs/Learn/CSS/Howto/Highlight_first_line)
  - : Find out how to target the first line of text in a paragraph with the {{cssxref("::first-line")}} pseudo-element.
- [How do I highlight the first paragraph in an article?](/en-US/docs/Learn/CSS/Howto/Highlight_first_para)
  - : Find out how to target the first paragraph with the {{cssxref(":first-child")}} pseudo-class.
- [How do I highlight a paragraph only if it comes right after a heading?](/en-US/docs/Learn/CSS/Howto/Highlight_para_after_h1)
  - : Combinators can help you to precisely target elements based on where they are in the document; this tutorial explains how to use them to apply CSS to a paragraph only if it immediately follows a heading.

### Text styling lessons and guides

- [How to style text](/en-US/docs/Learn/CSS/Styling_text/Fundamentals)
- [How to customize a list of elements](/en-US/docs/Learn/CSS/Styling_text/Styling_lists)
- [How to style links](/en-US/docs/Learn/CSS/Styling_text/Styling_links)
- [CSS Selectors](/en-US/docs/Learn/CSS/Building_blocks/Selectors)

## CSS Layout

- [How do I center an item?](/en-US/docs/Learn/CSS/Howto/Center_an_item)
  - : Centering an item inside another box horizontally and vertically used to be tricky, however Flexbox now makes it simple.

### Layout guides

- [Using CSS Flexbox](/en-US/docs/Web/CSS/CSS_Flexible_Box_Layout/Basic_Concepts_of_Flexbox)
- [Using CSS multi-column layouts](/en-US/docs/Web/CSS/CSS_Columns/Using_multi-column_layouts)
- [Using CSS Grid Layout](/en-US/docs/Web/CSS/CSS_Grid_Layout/Basic_Concepts_of_Grid_Layout)
- [Using CSS generated content](/en-US/docs/Learn/CSS/Howto/Generated_content)

> **Note:** We have a cookbook dedicated to [CSS Layout solutions](/en-US/docs/Web/CSS/Layout_cookbook), with fully worked examples and explanations of common layout tasks.
