---
title: Contributing to MDN
slug: MDN/Contribute
tags:
  - Guide
  - Landing
  - MDN Meta
---
{{MDNSidebar}}

MDN Web Docs needs your help! We have a large number of typos to fix, examples to write, bugs to fix, people to talk to, and more, and the number is growing as more people start using the site. This page outlines what you can do to help.

> **Note:** If you haven't contributed to MDN previously, the [Getting Started](/en-US/docs/MDN/Contribute/Getting_started) guide explains the process in four simple steps. Good news, you're already on step 2: "Picking a task to complete."!

## What can I do to help?

There are multiple avenues you can take to contribute to MDN depending on your skillset and interests. Along with each task we provide a short description and an approximate time that each type of task typically takes.

If you are not sure what to do, you are always welcome to [ask for help](/en-US/docs/MDN/Contribute/Getting_started#step_4_ask_for_help).

### Primary contribution types

The links in this section lead to detailed guides explaining how to do a particular contribution task that we are most interested in getting community help with, either because they are a critical function, and/or because they have a large backlog associated with them. Please consider helping out with these tasks before you consider contributing in other ways.

<table class="standard-table">
  <thead>
    <tr>
      <th scope="col">Tasks</th>
      <th scope="col">Description</th>
      <th scope="col">Skillset required</th>
    </tr>
  </thead>
  <tbody>
    <tr>
      <td>
        <a href="/en-US/docs/MDN/Contribute/Fixing_MDN_content_bugs"
          >Fixing MDN content bugs</a
        >
      </td>
      <td>
        Our <a href="https://github.com/mdn/content/issues">content repo</a> is
        where people submit issues to report problems found with MDN docs. We get a lot of content bugs, and any help
        you can give in fixing them would be much appreciated.
      </td>
      <td>
        <ul>
          <li>
            Knowledge of the web technologies you choose to help with (e.g.
            JavaScript, CSS).
          </li>
          <li>
            A reasonable understanding of the English language (don't worry if
            your English is not perfect; we can help you with it).
          </li>
        </ul>
      </td>
    </tr>
    <tr>
      <td>
        <a href="https://github.com/mdn/content/blob/main/REVIEWING.md"
          >Reviewing MDN edits</a
        >
      </td>
      <td>
        People submit pull requests on our
        <a href="https://github.com/mdn/content">content repo</a> all the time
        to update MDN content, and we need help reviewing them. Head over to our
        <a href="https://github.com/mdn/content/blob/main/REVIEWING.md"
          >REVIEWING.md</a
        >
        page to find out how the reviewing process works, and how you can get
        involved.
      </td>
      <td>
        <ul>
          <li>
            Knowledge of the web technologies you choose to help with (e.g.
            JavaScript, CSS).
          </li>
          <li>
            A reasonable understanding of the English language (don't worry if
            your English is not perfect; we can help you with it).
          </li>
        </ul>
      </td>
    </tr>
    <tr>
      <td>
        <a href="/en-US/docs/MDN/Contribute/Help_beginners"
          >Help beginners to learn on MDN</a
        >
      </td>
      <td>
        Our <a href="/en-US/docs/Learn">Learn web development</a> pages get over
        a million views per month and have
        <a href="https://discourse.mozilla.org/c/mdn/learn/250"
          >active forums</a
        >
        where people go to ask for general help, or request that their
        assessments be marked. We'd love some help with answering posts and
        growing our learning community.
      </td>
      <td>
        <ul>
          <li>
            Knowledge of the web technologies you choose to help with (e.g.
            JavaScript, CSS).
          </li>
          <li>
            Enthusiasm for explaining technical topics and helping beginners
            learn to code.
          </li>
          <li>
            Reasonable proficiency with the English language; it really doesn't
            need to be perfect.
          </li>
        </ul>
      </td>
    </tr>
  </tbody>
</table>

We will add more tasks here as time goes on.

#### Priority ratings

You can also look at priority ratings to give you an idea of what the most important work is to work on — we've started giving content bug issues labels of P0, P1, P2, P3, and P4 to signify how important they are, with lower numbers being more important than higher numbers.

These are figured out during the regular MDN bug triage process, based on the [MDN documentation priority list](/en-US/docs/MDN/Contribute/Documentation_priorities).

### Other task types

If our main priorities listed above don't interest you, you can find a number of other, more general task types to get involved with below, split up by skillset.

If you are more interested in words, you could do the following:

- [Update an existing article with new information](/en-US/docs/MDN/Contribute/Howto/Create_and_edit_pages#editing_an_existing_page) (5 minutes-1 hour)
- [Write a new entry in the Glossary](/en-US/docs/MDN/Contribute/Howto/Write_a_new_entry_in_the_Glossary) (15 minutes-1 hour)

If you are more interested in code, you could try your hand at the following:

- [Convert code samples to be "live"](/en-US/docs/MDN/Contribute/Howto/Convert_code_samples_to_be_live) (30 minutes)
- [Send a code patch to the Yari codebase](https://github.com/mdn/yari) (1 hour)
- [Write an interactive example](https://github.com/mdn/interactive-examples/blob/master/CONTRIBUTING.md) (1 hour)

If you are interested in words _and_ code, you could try your hand at the following:

- [Write or update an API reference](/en-US/docs/MDN/Contribute/Howto/Write_an_API_reference) (30 minutes to 2 hours, or more)
- [Write a new article on a topic you are familiar with](https://github.com/mdn/content#adding-a-new-document) (1 hour or more)
- [Add or update browser compatibility data on a reference page](/en-US/docs/MDN/Structures/Compatibility_tables) (30 minutes to 1 hour)

> **Note:** If you have found something that is incorrect on MDN but you're not sure how to fix it, you can report problems by [filing a documentation issue](https://github.com/mdn/content/issues/new/choose). Please give the issue a descriptive title. (It's not helpful to say "Dead link" without saying where you found the link).

## Other useful pages

{{LandingPageListSubPages()}}
